spacepy.radbelt.diff_LL — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- radbelt - Functions supporting radiation belt diffusion codes »

# spacepy.radbelt.diff_LL

`spacepy.radbelt.` `diff_LL`(r, grid, f, Tdelta, Telapsed, params=None)

  calculate the diffusion in L at constant mu,K coordinates time units

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- radbelt - Functions supporting radiation belt diffusion codes »